@@ -29,17 +29,16 @@
 
 namespace KScreen
 {
-
 using namespace KWayland::Server;
 
 class WaylandConfigReader
 {
-
 public:
-    //static QList<KWayland::Server::OutputInterface*> outputsFromConfig(const QString &configfile, KWayland::Server::Display *display);
-    static void outputsFromConfig(const QString &configfile, KWayland::Server::Display *display, QList<KWayland::Server::OutputDeviceInterface*>& outputs);
-    static OutputDeviceInterface* createOutputDevice(const QVariantMap &outputConfig, KWayland::Server::Display *display);
-    static QList<KWayland::Server::OutputInterface*> createOutputs(KWayland::Server::Display *display, QList<KWayland::Server::OutputDeviceInterface*>& outputdevices);
+    // static QList<KWayland::Server::OutputInterface*> outputsFromConfig(const QString &configfile, KWayland::Server::Display *display);
+    static void outputsFromConfig(const QString &configfile, KWayland::Server::Display *display, QList<KWayland::Server::OutputDeviceInterface *> &outputs);
+    static OutputDeviceInterface *createOutputDevice(const QVariantMap &outputConfig, KWayland::Server::Display *display);
+    static QList<KWayland::Server::OutputInterface *> createOutputs(KWayland::Server::Display *display,
+                                                                    QList<KWayland::Server::OutputDeviceInterface *> &outputdevices);
 
     static QSize sizeFromJson(const QVariant &data);
     static QRect rectFromJson(const QVariant &data);
